______________________________________________________________________

## name: Bug report about: Report a bug in har-capture title: '' labels: bug assignees: ''

## Description

A clear description of the bug.

## Steps to Reproduce

1.
1.
1.

## Expected Behavior

What you expected to happen.

## Actual Behavior

What actually happened.

## Environment

- har-capture version:
- Python version:
- OS:

## Additional Context

Any other context, error messages, or screenshots.
